# WARNING: This package is synced with FC

%global major 0
%global apiversion 0.18
%define libname %mklibname ixion %apiversion %major
%define devname %mklibname -d ixion

Name: libixion
Version: 0.19.0
Release: %mkrel 1
Summary: A general purpose formula parser & interpreter library

Group: System/Libraries
License: MPLv2.0
URL: https://gitlab.com/ixion/ixion
Source0: https://kohei.us/files/ixion/src/%{name}-%{version}.tar.xz

BuildRequires: boost-devel
BuildRequires: help2man
BuildRequires: automake
BuildRequires: pkgconfig(mdds-2.1)
BuildRequires: pkgconfig(python3)
BuildRequires: pkgconfig(spdlog)
ExcludeArch:   armv5tl

%description
Ixion is a general purpose formula parser & interpreter that can calculate
multiple named targets, or "cells".

The goal of this project is to create a library for calculating the results of
formula expressions stored in multiple named targets, or “cells”. The cells can
be referenced from each other, and the library takes care of resolving their
dependencies automatically upon calculation. The caller can run the calculation
routine either in a single-threaded mode, or a multi-threaded mode. The library
also supports re-calculations where the contents of one or more cells have been
modified since the last calculation, and a partial calculation of only the
affected cells need to be calculated.

Supported features:
- Each calculation session is defined in a plain text file, which is parsed and
  interpreted by the Ixion parser.
- Fully threaded calculation.
- Name resolution using A1-style references.
- Support 2D cell references and named expressions.
- Support range references.
- Dependency tracking during both full calculation and partial re-calculation.
- Inline strings.
- Volatile functions. The framework for volatile functions is implemented. We
  just need to implement more functions.

%package -n %libname
Summary: A general purpose formula parser & interpreter library
Group: System/Libraries

%description -n %libname
Ixion is a general purpose formula parser & interpreter that can calculate
multiple named targets, or "cells".

The goal of this project is to create a library for calculating the results of
formula expressions stored in multiple named targets, or “cells”. The cells can
be referenced from each other, and the library takes care of resolving their
dependencies automatically upon calculation. The caller can run the calculation
routine either in a single-threaded mode, or a multi-threaded mode. The library
also supports re-calculations where the contents of one or more cells have been
modified since the last calculation, and a partial calculation of only the
affected cells need to be calculated.

Supported features:
- Each calculation session is defined in a plain text file, which is parsed and
  interpreted by the Ixion parser.
- Fully threaded calculation.
- Name resolution using A1-style references.
- Support 2D cell references and named expressions.
- Support range references.
- Dependency tracking during both full calculation and partial re-calculation.
- Inline strings.
- Volatile functions. The framework for volatile functions is implemented. We
  just need to implement more functions.

%package -n %devname
Summary: Development files for %{name}
Group: Development/C
Requires: %{libname} = %{version}-%{release}

%description -n %devname
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%package tools
Summary: Testing tools for libixion
Group: Office/Utilities
Requires: %{libname} = %{version}-%{release}

%description tools
Testing tools for %{name}.

%package -n python3-%name
Summary: Python 3 bindings for libixion
Group: System/Libraries
Suggests: %{name}-doc = %{version}-%{release}

%description -n python3-%name
Python 3 bindings for %{name}.

%package doc
Summary: API documentation for %{name}
Group:  Documentation
BuildArch: noarch

%description doc
API documentation for %{name}.

%prep
%autosetup -p1

%build
autoreconf -fi
%configure --disable-silent-rules --disable-static
%make_build

%install
%make_install

# create and install man pages
export LD_LIBRARY_PATH=%{buildroot}%{_libdir}${LD_LIBRARY_PATH:+:${LD_LIBRARY_PATH}}
help2man -S '%{name} %{version}' -N -n 'formula tokenizer' -o ixion-formula-tokenizer.1 ./src/ixion-formula-tokenizer
help2man -S '%{name} %{version}' -N -n 'parser' -o ixion-parser.1 ./src/ixion-parser
help2man -S '%{name} %{version}' -N -n 'sorter' -o ixion-sorter.1 ./src/ixion-sorter
install -m 0755 -d %{buildroot}/%{_mandir}/man1
install -m 0644 ixion-*.1 %{buildroot}/%{_mandir}/man1

# generate docs
# make doc

%check
export LD_LIBRARY_PATH=%{buildroot}%{_libdir}${LD_LIBRARY_PATH:+:${LD_LIBRARY_PATH}}
%ifnarch %{ix86}
%make_build check
%endif

%files -n %libname
%doc AUTHORS
%license LICENSE
%{_libdir}/%{name}-%{apiversion}.so.%{major}
%{_libdir}/%{name}-%{apiversion}.so.%{major}.*

%files -n %devname
%{_includedir}/%{name}-%{apiversion}
%{_libdir}/%{name}-%{apiversion}.so
%{_libdir}/pkgconfig/%{name}-%{apiversion}.pc

%files tools
%{_bindir}/ixion-formula-tokenizer
%{_bindir}/ixion-parser
%{_bindir}/ixion-sorter
%{_mandir}/man1/ixion-formula-tokenizer.1*
%{_mandir}/man1/ixion-parser.1*
%{_mandir}/man1/ixion-sorter.1*

%files -n python3-%name
%{python3_sitearch}/ixion.so

%files doc
%license LICENSE
%doc doc/python


%changelog
* Tue Apr 02 2024 ns80 <ns80> 0.19.0-1.mga9
+ Revision: 2053955
- new version 0.19.0 for libreoffice 7.6.6

* Sat Dec 24 2022 wally <wally> 0.17.0-5.mga9
+ Revision: 1926492
- rebuild for boost 1.81.0

* Sun Jul 03 2022 wally <wally> 0.17.0-4.mga9
+ Revision: 1867268
- rebuild for boost 1.79.0

* Wed Mar 30 2022 umeabot <umeabot> 0.17.0-3.mga9
+ Revision: 1833912
- Mageia 9 Mass Rebuild

* Tue Mar 01 2022 mrambo3501 <mrambo3501> 0.17.0-2.mga9
+ Revision: 1787150
- rebuild for python-3.10

* Fri Feb 04 2022 tv <tv> 0.17.0-1.mga9
+ Revision: 1771406
- new upstream release

* Wed Dec 22 2021 wally <wally> 0.16.1-9.mga9
+ Revision: 1763308
- rebuild for missing pkgs in armv7hl

* Sun Dec 19 2021 wally <wally> 0.16.1-8.mga9
+ Revision: 1762594
- rebuild for boost 1.78.0

* Thu Sep 09 2021 wally <wally> 0.16.1-7.mga9
+ Revision: 1744710
- fix RPATH issue with autoreconf
- let post %%install scriptlets remove .la files
- drop old obsoletes
- rebuild for boost 1.77.0

* Fri May 14 2021 wally <wally> 0.16.1-5.mga9
+ Revision: 1722977
- rebuild for boost 1.76.0

* Sun Mar 28 2021 tv <tv> 0.16.1-4.mga9
+ Revision: 1711295
- rebuild for python 3.9

* Thu Dec 31 2020 wally <wally> 0.16.1-3.mga8
+ Revision: 1666774
- rebuild for boost 1.75.0

* Sun Dec 20 2020 wally <wally> 0.16.1-2.mga8
+ Revision: 1662016
- rebuild for boost 1.74.0

* Tue Sep 29 2020 tv <tv> 0.16.1-1.mga8
+ Revision: 1631153
- 0.16.1

* Thu Sep 24 2020 tv <tv> 0.16.0-1.mga8
+ Revision: 1629795
- 0.16.0

* Sun May 03 2020 wally <wally> 0.15.0-6.mga8
+ Revision: 1578071
- rebuild for boost 1.73.0

* Wed Feb 19 2020 umeabot <umeabot> 0.15.0-5.mga8
+ Revision: 1544802
- Mageia 8 Mass Rebuild

* Sun Jan 26 2020 wally <wally> 0.15.0-4.mga8
+ Revision: 1483389
- rebuild for boost 1.72.0
- replace deprecated %%configure2_5x

* Tue Sep 10 2019 wally <wally> 0.15.0-3.mga8
+ Revision: 1439452
- add patch to fix overlinking

* Tue Sep 10 2019 wally <wally> 0.15.0-2.mga8
+ Revision: 1439451
- add patch to fix linking with boost
- rebuild for python3.8

* Mon Aug 26 2019 tv <tv> 0.15.0-1.mga8
+ Revision: 1432379
- "fix" underlinking
- new release

* Wed Jan 09 2019 shlomif <shlomif> 0.14.1-2.mga7
+ Revision: 1353347
- Rebuild for python3 3.7

* Tue Oct 30 2018 tv <tv> 0.14.1-1.mga7
+ Revision: 1326724
- new release

* Tue Oct 16 2018 wally <wally> 0.14.0-2.mga7
+ Revision: 1321054
- rebuild for new boost 1.68.0

* Mon Sep 03 2018 tv <tv> 0.14.0-1.mga7
+ Revision: 1256685
- new release

* Sun Sep 02 2018 tv <tv> 0.13.0-4.mga7
+ Revision: 1256150
- fix build with mdds 1.4

* Mon Dec 25 2017 wally <wally> 0.13.0-2.mga7
+ Revision: 1184755
- rebuild for new boost

* Tue Nov 21 2017 tv <tv> 0.13.0-1.mga7
+ Revision: 1178145
- new release

* Sat Sep 16 2017 tv <tv> 0.12.2-3.mga7
+ Revision: 1154536
- rebuild with latest boost

* Sat Aug 05 2017 pterjan <pterjan> 0.12.2-2.mga7
+ Revision: 1135255
- Rebuild for python 3.6

* Sun Feb 26 2017 tv <tv> 0.12.2-1.mga6
+ Revision: 1087984
- new release

* Fri Sep 23 2016 tv <tv> 0.12.0-3.mga6
+ Revision: 1055572
- just exclude on armv5tl

* Fri Sep 23 2016 tv <tv> 0.12.0-2.mga6
+ Revision: 1055571
- use --disable-threads on armv5 (debian#727621: armel: std::future appears to be broken)

* Mon Sep 19 2016 tv <tv> 0.12.0-1.mga6
+ Revision: 1054523
- use %%license
- add doc subpkg
- use %%autosetup
- fix tools description
- new release

* Wed Mar 02 2016 tv <tv> 0.11.0-1.mga6
+ Revision: 983097
- adjust rm to py2 -> py3 switch
- new release
- switch to python3
- fix python subpkg summary

* Fri Dec 25 2015 tv <tv> 0.9.1-5.mga6
+ Revision: 914721
- rebuild for new boost 1.60

* Fri Dec 25 2015 tv <tv> 0.9.1-4.mga6
+ Revision: 914682
- rebuild for boost 1.60
- use BR style for python-devel

* Fri Sep 25 2015 tv <tv> 0.9.1-3.mga6
+ Revision: 883537
- rebuild for new boost

* Wed Aug 26 2015 tv <tv> 0.9.1-2.mga6
+ Revision: 869853
- rebuild with gcc5

* Fri Jul 31 2015 neoclust <neoclust> 0.9.1-1.mga6
+ Revision: 859834
- New version 0.9.1
- Rebuild against new boost

* Wed Oct 15 2014 umeabot <umeabot> 0.7.0-5.mga5
+ Revision: 748054
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.7.0-4.mga5
+ Revision: 681544
- Mageia 5 Mass Rebuild

* Fri Aug 08 2014 wally <wally> 0.7.0-3.mga5
+ Revision: 661131
- fix lib pkg name and summary

* Thu Jul 31 2014 tv <tv> 0.7.0-2.mga5
+ Revision: 658682
- fix package names
- rebuild for having a fixed package

* Thu Jul 31 2014 tv <tv> 0.7.0-1.mga5
+ Revision: 658603
- imported package libixion


* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.7.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Thu May 22 2014 David Tardon <dtardon@redhat.com> - 0.7.0-1
- initial import
